| Title: | Companion Package for 'Reproducible Research Using R' |
|---|---|
| Description: | Provides teaching datasets and helper functions to support the open educational resource Martinez (2026) "Reproducible Research Using R" <doi:10.5281/zenodo.19136755>. The package includes datasets used throughout the book and utilities to list and copy chapter scripts shipped with the package. |
| Authors: | Christian Martinez [aut, cre] |
| Maintainer: | Christian Martinez <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.1 |
| Built: | 2026-05-25 07:58:26 UTC |
| Source: | https://github.com/martinezc1/reproresearchr |
Copy or run a textbook chapter script
chapter_script( chapter, type = c("full", "helper"), dest, run = FALSE, overwrite = FALSE, open = FALSE )chapter_script( chapter, type = c("full", "helper"), dest, run = FALSE, overwrite = FALSE, open = FALSE )
chapter |
Chapter number (e.g., 1, 2, 3). |
type |
Script type: "full" or "helper". |
dest |
Directory to copy the script into. |
run |
If TRUE, source() the script after copying. |
overwrite |
If TRUE, overwrite an existing file. |
open |
If TRUE, attempt to open the copied script in RStudio. |
Path to the copied script (invisibly if run = TRUE).
tmp <- tempdir() chapter_script(3, "helper", dest = tmp, overwrite = TRUE) tmp <- tempdir() chapter_script(3, "helper", dest = tmp, open = TRUE, overwrite = TRUE)tmp <- tempdir() chapter_script(3, "helper", dest = tmp, overwrite = TRUE) tmp <- tempdir() chapter_script(3, "helper", dest = tmp, open = TRUE, overwrite = TRUE)
A teaching dataset used in *Reproducible Research Using R*. This dataset is used for examples involving descriptive statistics, visualization, correlation, and regression.
exam_dataexam_data
A data frame with 100 rows and 5 variables:
Student identifier.
Number of hours spent studying.
Exam score.
Self-reported anxiety score.
Whether the student is a first-generation college student (Yes/No).
Created for the textbook *Reproducible Research Using R*.
A teaching dataset used in *Reproducible Research Using R*. This dataset is used for examples involving categorical data analysis and group comparisons.
infection_treatmentsinfection_treatments
A data frame with 150 rows and 2 variables:
Type of infection.
Treatment administered.
Created for the textbook *Reproducible Research Using R*.
List available chapter scripts included with the package
list_chapters()list_chapters()
A data frame with columns: chapter, type, file.
list_chapters()list_chapters()
A teaching dataset used in *Reproducible Research Using R*. This dataset is primarily used for examples involving data visualization and linear regression.
pizza_pricespizza_prices
A data frame with 156 rows and 3 variables:
Week number of observation.
Total number of pizzas sold in that week.
Total revenue generated from pizza sales in that week.
Created for the textbook *Reproducible Research Using R*.